# SetPasswordRequest

A request to set a password for a user.

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**reset_token** | **str** | Unique reset token valid for 7 days. | [optional] 
**password** | **str** | The password the user to log in with. | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


